Appservice

Struct Appservice 

pub struct Appservice {
    pub homeserver_token: String,
    pub appservice_token: String,
    pub client: MatrixClient,
    /* private fields */
}

Fields

homeserver_token: Stringappservice_token: Stringclient: MatrixClient

Implementations

Source

impl Appservice

pub fn new( homeserver_token: impl Into<String>, appservice_token: impl Into<String>, client: MatrixClient, ) -> Self

pub fn with_appservice_id(self, appservice_id: impl Into<String>) -> Self

pub fn with_homeserver_name(self, homeserver_name: impl Into<String>) -> Self

pub fn with_user_prefix(self, user_prefix: impl Into<String>) -> Self

pub fn with_alias_prefix(self, alias_prefix: impl Into<String>) -> Self

pub fn with_user_namespace_regexes<I, S>(self, regexes: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

pub fn with_alias_namespace_regexes<I, S>(self, regexes: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

pub fn with_protocols<I, S>(self, protocols: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

pub fn with_handler(self, handler: Arc<dyn AppserviceHandler>) -> Self

pub fn get_intent(&self, localpart: &str) -> Intent

pub fn get_user_id(&self, localpart: &str) -> String

pub fn get_intent_for_suffix(&self, suffix: &str) -> Result<Intent>

pub fn get_user_id_for_suffix(&self, suffix: &str) -> Result<String>

pub fn get_intent_for_user_id(&self, user_id: &str) -> Intent

pub fn get_suffix_for_user_id(&self, user_id: &str) -> Result<Option<String>>

pub fn is_namespaced_user(&self, user_id: &str) -> bool

pub fn get_alias(&self, localpart: &str) -> String

pub fn get_alias_for_suffix(&self, suffix: &str) -> Result<String>

pub fn get_alias_localpart_for_suffix(&self, suffix: &str) -> Result<String>

pub fn get_suffix_for_alias(&self, alias: &str) -> Result<Option<String>>

pub fn is_namespaced_alias(&self, alias: &str) -> bool

pub async fn add_preprocessor(&self, preprocessor: Arc<dyn IPreprocessor>)

pub async fn set_room_directory_visibility( &self, network_id: &str, room_id: &str, visibility: &str, ) -> Result<Value>

pub fn router(&self) -> Router

pub async fn begin(&self) -> Result<()>

Present for API parity with the TypeScript SDK where the appservice starts its own web server. In Rust, server startup is controlled by the host application using router().

pub fn stop(&self)

Present for API parity with the TypeScript SDK.

pub async fn expect_ping_transaction(&self, transaction_id: impl Into<String>)

pub async fn expected_ping_transaction(&self) -> Option<String>

pub async fn ping_homeserver(&self) -> Result<PingHomeserverResponse>