pub struct MatrixBridge { /* private fields */ }Implementations
Sourceimpl MatrixBridge
impl MatrixBridge
pub fn new(bot_intent: Intent) -> Self
pub async fn map_virtual_user( &self, namespace: impl Into<String>, user_id: impl Into<String>, ) -> Result<()>
pub async fn resolve_virtual_user(&self, namespace: &str) -> Option<String>
Sourcepub async fn get_remote_user_info<T: DeserializeOwned>(
&self,
user_intent: &Intent,
) -> Result<T>
pub async fn get_remote_user_info<T: DeserializeOwned>( &self, user_intent: &Intent, ) -> Result<T>
Gets information about a remote user.
Sourcepub async fn set_remote_user_info<T: Serialize>(
&self,
user_intent: &Intent,
remote_info: &T,
) -> Result<()>
pub async fn set_remote_user_info<T: Serialize>( &self, user_intent: &Intent, remote_info: &T, ) -> Result<()>
Sets information about a remote user. Calling this function will map the provided remote user ID to the intent’s owner.
Sourcepub async fn get_remote_room_info<T: DeserializeOwned>(
&self,
matrix_room_id: &str,
) -> Result<T>
pub async fn get_remote_room_info<T: DeserializeOwned>( &self, matrix_room_id: &str, ) -> Result<T>
Gets information about a remote room.
Sourcepub async fn set_remote_room_info<T: Serialize>(
&self,
matrix_room_id: &str,
remote_info: &T,
) -> Result<()>
pub async fn set_remote_room_info<T: Serialize>( &self, matrix_room_id: &str, remote_info: &T, ) -> Result<()>
Sets information about a remote room. Calling this function will map the provided remote room ID to the matrix room ID.
Sourcepub async fn get_matrix_room_id_for_remote(
&self,
remote_room_id: &str,
) -> Result<String>
pub async fn get_matrix_room_id_for_remote( &self, remote_room_id: &str, ) -> Result<String>
Gets the Matrix room ID for the provided remote room ID.
Sourcepub async fn get_intent_for_remote(
&self,
remote_user_id: &str,
) -> Result<Intent>
pub async fn get_intent_for_remote( &self, remote_user_id: &str, ) -> Result<Intent>
Gets a Matrix user intent for the provided remote user ID.