pub struct ProfileCache { /* private fields */ }Implementations
Sourceimpl ProfileCache
impl ProfileCache
pub fn new(ttl: Duration) -> Self
pub async fn get(&self, user_id: &str) -> Option<MatrixProfile>
pub async fn put(&self, profile: MatrixProfile)
Sourcepub async fn get_or_fetch<F, Fut>(
&self,
user_id: &str,
fetch: F,
) -> Option<MatrixProfile>
pub async fn get_or_fetch<F, Fut>( &self, user_id: &str, fetch: F, ) -> Option<MatrixProfile>
Returns the cached profile for the given user ID, or fetches it using the provided async callback if not cached (or expired). The fetched profile is then stored in the cache.