Module models

Module models 

Modules

events
unstable

Structs

Account
Capabilities
CreateRoom
Crypto
EventContext
IdentityServerModels
KeyBackup
MSC2176
MSC2716BatchSendResponse
MXCUrl
MatrixError
MatrixProfile
OpenIDConnect
PLManager
Manages power levels for a Matrix room.
Policies
PowerLevels
ServerVersions
Space
Represents a Matrix Space, which is a special type of room used to group rooms.
Spaces
Threepid

Enums

Presence

Constants

ROOM_ADMIN_PL
Power level required to be considered a room admin.
ROOM_CREATOR_PL
Power level assigned to the room creator.