pub struct Space {
pub room_id: String,
pub children: Vec<String>,
pub parents: Vec<String>,
pub suggested: Vec<String>,
}Expand description
Represents a Matrix Space, which is a special type of room used to group rooms.
Fields
room_id: StringThe room ID of this space.
children: Vec<String>Child room IDs that belong to this space.
parents: Vec<String>Parent space room IDs for this space.
suggested: Vec<String>Suggested child rooms to show to new members.
Implementations
Sourceimpl Space
impl Space
pub fn new(room_id: impl Into<String>) -> Self
Sourcepub fn add_child(&mut self, room_id: impl Into<String>, suggested: bool)
pub fn add_child(&mut self, room_id: impl Into<String>, suggested: bool)
Adds a child room. If suggested is true, it will also appear in the suggested list.
Sourcepub fn remove_child(&mut self, room_id: &str)
pub fn remove_child(&mut self, room_id: &str)
Removes a child room from the space (including from suggested list).